# Pandas ML Quant

The Pandas Machine Learning Quant module is not only a pure python reimplementation of the famous 
[TA-Lib](http://mrjbq7.github.io/ta-lib/). There are also useful tools to plot data as well as to 
train neural networks while you never need to leave the world of pandas. 

## Installation
Follow the instructions on [https://github.com/KIC/pandas-ml-quant](https://github.com/KIC/pandas-ml-quant)

## Documentation
Check out the notebooks at [https://github.com/KIC/pandas-ml-quant/blob/master/notebooks](https://github.com/KIC/pandas-ml-quant/blob/master/notebooks)

